@@ -41,10 +41,8 @@ from urllib.parse import urlsplit
 from uuid import uuid4
 
 if TYPE_CHECKING:
-    try:
+    with suppress(ImportError):
         from aiobotocore.client import AioBaseClient
-    except ImportError:
-        pass
 
 from asgiref.sync import sync_to_async
 from boto3.s3.transfer import TransferConfig
@@ -470,7 +468,7 @@ class S3Hook(AwsBaseHook):
         :param bucket_name: the name of the bucket
         :param key: the path to the key
         """
-        prefix = re.split(r"[\[\*\?]", key, 1)[0]
+        prefix = re.split(r"[\[*?]", key, 1)[0]
         delimiter = ""
         paginator = client.get_paginator("list_objects_v2")
         response = paginator.paginate(Bucket=bucket_name, Prefix=prefix, Delimiter=delimiter)
@@ -572,7 +570,7 @@ class S3Hook(AwsBaseHook):
         for key in bucket_keys:
             prefix = key
             if wildcard_match:
-                prefix = re.split(r"[\[\*\?]", key, 1)[0]
+                prefix = re.split(r"[\[*?]", key, 1)[0]
 
             paginator = client.get_paginator("list_objects_v2")
             response = paginator.paginate(Bucket=bucket, Prefix=prefix, Delimiter=delimiter)
@@ -1017,7 +1015,7 @@ class S3Hook(AwsBaseHook):
         :param delimiter: the delimiter marks key hierarchy
         :return: the key object from the bucket or None if none has been found.
         """
-        prefix = re.split(r"[\[\*\?]", wildcard_key, 1)[0]
+        prefix = re.split(r"[\[*?]", wildcard_key, 1)[0]
         key_list = self.list_keys(bucket_name, prefix=prefix, delimiter=delimiter)
         key_matches = [k for k in key_list if fnmatch.fnmatch(k, wildcard_key)]
         if key_matches:
